From a175a2637795983b0f631f2c3e955c2ad1135bf1 Mon Sep 17 00:00:00 2001
From: Mirsal Ennaime <mirsal.ennaime@gmail.com>
Date: Fri, 30 May 2008 09:53:35 +0200
Subject: [PATCH] Update the services discovery modules localized name in the playlist
 when services_discovery_SetLocalizedName is called.

---
 src/playlist/services_discovery.c |   27 +++++++++++++++++++++++++++
 1 files changed, 27 insertions(+), 0 deletions(-)

diff --git a/src/playlist/services_discovery.c b/src/playlist/services_discovery.c
index b68bad6..9bffc57 100644
--- a/src/playlist/services_discovery.c
+++ b/src/playlist/services_discovery.c
@@ -32,6 +32,8 @@
 #include "../libvlc.h"
 
 static void RunSD( services_discovery_t *p_sd );
+static void playlist_sd_update_category_name( services_discovery_t* p_sd, 
+                                                        const char* psz );
 
 /*
  * Services discovery
@@ -148,6 +150,7 @@ services_discovery_SetLocalizedName ( services_discovery_t * p_sd, const char *p
 {
     free( p_sd->psz_localized_name );
     p_sd->psz_localized_name = strdup(psz);
+    playlist_sd_update_category_name( p_sd, psz );
 }
 
 /***********************************************************************
@@ -430,3 +433,27 @@ bool playlist_IsServicesDiscoveryLoaded( playlist_t * p_playlist,
     return false;
 }
 
+static void playlist_sd_update_category_name( services_discovery_t* p_sd,
+                                                        const char* psz )
+{
+    playlist_t* p_playlist = pl_Yield( (vlc_object_t*) p_sd );
+    struct playlist_services_discovery_support_t* p_sds = NULL;
+    int i;
+
+    PL_LOCK;
+    for( i = 0 ; i < p_playlist->i_sds ; i ++ )
+    {
+        if( (vlc_object_t*) p_sd->i_object_id ==
+                (vlc_object_t*) (p_playlist->pp_sds[i]->p_sd)->i_object_id )
+        {
+            p_sds = p_playlist->pp_sds[i];
+            vlc_object_lock( (vlc_object_t*) p_input );
+            p_sds->p_cat->p_input->psz_name = strdup( psz );
+            vlc_object_unlock( (vlc_object_t*) p_input );
+            break;
+        }
+    }
+    PL_UNLOCK;
+
+    pl_Release( p_playlist );
+}
-- 
1.5.4.3

